@@ -1,11 +1,8 @@
-import sys
-sys.path.append('..')
-sys.path.append('../Regression/')
 import numpy as np
 import scipy.optimize as optim
 import scipy.stats as stats
 import copy
-from Regression import Simple
+import MCMAlgorithms.Regression.Simple as Simple
 
 
 class GreyAnalysis:
